package org.fuseri.modulecertificate.certificate;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.Page;
import org.springframework.data.domain.Pageable;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.server.ResponseStatusException;

import java.util.List;

@Service
public class CertificateService {

    private final CertificateRepository certificateRepository;

    @Autowired
    public CertificateService(CertificateRepository certificateRepository) {
        this.certificateRepository = certificateRepository;
    }

    @Transactional(readOnly = true)
    public Certificate findById(Long id) {
        return certificateRepository.findById(id)
                .orElseThrow(() -> new ResponseStatusException(HttpStatus.NOT_FOUND, "Certificate with id: " + id + " was not found."));
    }

    @Transactional(readOnly = true)
    public List<Certificate> findByUserId(Long userId) {
        return certificateRepository.findCertificateByUserId(userId);
    }

    @Transactional(readOnly = true)
    public List<Certificate> findByUserIdAndCourseId(Long userId, Long courseId) {
        return certificateRepository.findCertificateByUserIdAndCourseId(userId, courseId);
    }

    @Transactional(readOnly = true)
    public Certificate save(Certificate certificate) {
        return certificateRepository.save(certificate);
    }

    @Transactional(readOnly = true)
    public void delete(Long certificateId) {
        certificateRepository.deleteById(certificateId);
    }

    @Transactional(readOnly = true)
    public Page<Certificate> findAll(Pageable pageable) {
        return certificateRepository.findAll(pageable);
    }
}

